module Core.HTTP where

import qualified Core.Configuration         as Conf
import qualified Core.Handlers              as Handle

import Network.Wai.Handler.Warp             (Port, run)
import Network.Wai.Middleware.RequestLogger (logStdoutDev)
import Network.Wai.Middleware.Static

import Web.Twain

-- Get the port to listen on from the ENV and start the webserver
main :: IO ()
main = do
  port <- Conf.appPort
  run (read port :: Int) $
    foldr ($) (notFound Handle.missing) app

-- These Middlewares are executed before any routes are reached
preProcessors :: [Middleware]
preProcessors = [ logStdoutDev
                , staticPolicy $ noDots >-> addBase "data/assets/public"
                ]

-- The application's routes expressed as a list of WAI Middlewares
routes :: [Middleware]
routes =
  [ get "/" Handle.index
  , get "/echo/:testParam" Handle.testRoute
  ]

-- Combine our Preprocessor Middlewares and Routes to create an App to run
app :: [Middleware]
app = preProcessors ++ routes
